@@ -1,7 +1,8 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
-** Contact: Qt Software Information (qt-info@nokia.com)
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
@@ -20,10 +21,9 @@
 ** ensure the GNU Lesser General Public License version 2.1 requirements
 ** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Nokia gives you certain
-** additional rights. These rights are described in the Nokia Qt LGPL
-** Exception version 1.0, included in the file LGPL_EXCEPTION.txt in this
-** package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
@@ -33,8 +33,8 @@
 ** ensure the GNU General Public License version 3.0 requirements will be
 ** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -100,7 +100,8 @@ public:
         LinkName,
         CanonicalName,
         CanonicalPathName,
-        BundleName
+        BundleName,
+        NFileNames = 9
     };
     enum FileOwner {
         OwnerUser,
@@ -193,7 +194,7 @@ protected:
     QAbstractFileEngine();
     QAbstractFileEngine(QAbstractFileEnginePrivate &);
 
-    QAbstractFileEnginePrivate *d_ptr;
+    QScopedPointer<QAbstractFileEnginePrivate> d_ptr;
 private:
     Q_DECLARE_PRIVATE(QAbstractFileEngine)
     Q_DISABLE_COPY(QAbstractFileEngine)
@@ -237,7 +238,7 @@ private:
     friend class QDirIterator;
     friend class QDirIteratorPrivate;
     void setPath(const QString &path);
-    QAbstractFileEngineIteratorPrivate *d;
+    QScopedPointer<QAbstractFileEngineIteratorPrivate> d;
 };
 
 QT_END_NAMESPACE
