@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -213,6 +213,9 @@
 #ifndef QT_NO_UNDOVIEW
 #  define QT_NO_UNDOVIEW
 #endif
+#ifndef QT_NO_GESTURES
+#  define QT_NO_GESTURES
+#endif
 
 /* Widgets */
 #ifndef QT_NO_LCDNUMBER
