@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -52,24 +50,29 @@
 #include <QtCore/qstringlist.h>
 #endif
 
-QT_BEGIN_HEADER
-
-QT_MODULE(Core)
-
 #if defined(Q_WS_WIN) && !defined(tagMSG)
 typedef struct tagMSG MSG;
 #endif
 
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE
+
+QT_MODULE(Core)
+
 class QCoreApplicationPrivate;
 class QTextCodec;
 class QTranslator;
 class QPostEventList;
 class QStringList;
 
+#define qApp QCoreApplication::instance()
+
 class Q_CORE_EXPORT QCoreApplication : public QObject
 {
     Q_OBJECT
     Q_PROPERTY(QString applicationName READ applicationName WRITE setApplicationName)
+    Q_PROPERTY(QString applicationVersion READ applicationVersion WRITE setApplicationVersion)
     Q_PROPERTY(QString organizationName READ organizationName WRITE setOrganizationName)
     Q_PROPERTY(QString organizationDomain READ organizationDomain WRITE setOrganizationDomain)
 
@@ -93,6 +96,8 @@ public:
     static QString organizationName();
     static void setApplicationName(const QString &application);
     static QString applicationName();
+    static void setApplicationVersion(const QString &version);
+    static QString applicationVersion();
 
     static QCoreApplication *instance() { return self; }
 
@@ -117,6 +122,7 @@ public:
 
     static QString applicationDirPath();
     static QString applicationFilePath();
+    static qint64 applicationPid();
 
 #ifndef QT_NO_LIBRARY
     static void setLibraryPaths(const QStringList &);
@@ -133,11 +139,11 @@ public:
     // ### Qt 5: merge
     static QString translate(const char * context,
                              const char * key,
-                             const char * comment = 0,
+                             const char * disambiguation = 0,
                              Encoding encoding = CodecForTr);
     static QString translate(const char * context,
                              const char * key,
-                             const char * comment,
+                             const char * disambiguation,
                              Encoding encoding, int n);
 
     static void flush();
@@ -159,7 +165,7 @@ public:
     virtual bool winEventFilter(MSG *message, long *result);
 #endif
 
-#ifdef Q_OS_UNIX
+#if defined(Q_OS_UNIX) && !defined(Q_OS_SYMBIAN)
     static void watchUnixSignal(int signal, bool watch);
 #endif
 
@@ -189,6 +195,8 @@ private:
     void init();
 
     static QCoreApplication *self;
+    
+    Q_DISABLE_COPY(QCoreApplication)
 
     friend class QEventDispatcherUNIXPrivate;
     friend class QApplication;
@@ -242,16 +250,16 @@ inline QString QCoreApplication::translate(const char *, const char *sourceText,
 // ### merge the four functions into two (using "int n = -1")
 #define Q_DECLARE_TR_FUNCTIONS(context) \
 public: \
-    static inline QString tr(const char *sourceText, const char *comment = 0) \
-        { return QCoreApplication::translate(#context, sourceText, comment); } \
-    static inline QString trUtf8(const char *sourceText, const char *comment = 0) \
-        { return QCoreApplication::translate(#context, sourceText, comment, \
+    static inline QString tr(const char *sourceText, const char *disambiguation = 0) \
+        { return QCoreApplication::translate(#context, sourceText, disambiguation); } \
+    static inline QString trUtf8(const char *sourceText, const char *disambiguation = 0) \
+        { return QCoreApplication::translate(#context, sourceText, disambiguation, \
                                              QCoreApplication::UnicodeUTF8); } \
-    static inline QString tr(const char *sourceText, const char *comment, int n) \
-        { return QCoreApplication::translate(#context, sourceText, comment, \
+    static inline QString tr(const char *sourceText, const char *disambiguation, int n) \
+        { return QCoreApplication::translate(#context, sourceText, disambiguation, \
                                              QCoreApplication::CodecForTr, n); } \
-    static inline QString trUtf8(const char *sourceText, const char *comment, int n) \
-        { return QCoreApplication::translate(#context, sourceText, comment, \
+    static inline QString trUtf8(const char *sourceText, const char *disambiguation, int n) \
+        { return QCoreApplication::translate(#context, sourceText, disambiguation, \
                                              QCoreApplication::UnicodeUTF8, n); } \
 private:
 
@@ -266,6 +274,8 @@ Q_CORE_EXPORT QString decodeMSG(const MSG &);
 Q_CORE_EXPORT QDebug operator<<(QDebug, const MSG &);
 #endif
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QCOREAPPLICATION_H
