@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -46,9 +44,16 @@
 
 #include <QtGui/qwindowdefs.h>
 #include <QtCore/qstring.h>
+#include <QtCore/qsharedpointer.h>
+
+#if defined(Q_WS_X11) || defined(Q_WS_QWS)
+typedef struct FT_FaceRec_* FT_Face;
+#endif
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 class QFontPrivate;                                     /* don't touch */
@@ -56,10 +61,6 @@ class QStringList;
 class QVariant;
 class Q3TextFormatCollection;
 
-#if defined(Q_WS_X11) || defined(Q_WS_QWS)
-typedef struct FT_FaceRec_* FT_Face;
-#endif
-
 class Q_GUI_EXPORT QFont
 {
     Q_GADGET
@@ -71,21 +72,25 @@ public:
         Courier,    TypeWriter = Courier,
         OldEnglish, Decorative = OldEnglish,
         System,
-        AnyStyle
+        AnyStyle,
+        Cursive,
+        Monospace,
+        Fantasy
     };
 
     enum StyleStrategy {
-        PreferDefault    = 0x0001,
-        PreferBitmap     = 0x0002,
-        PreferDevice     = 0x0004,
-        PreferOutline    = 0x0008,
-        ForceOutline     = 0x0010,
-        PreferMatch      = 0x0020,
-        PreferQuality    = 0x0040,
-        PreferAntialias  = 0x0080,
-        NoAntialias      = 0x0100,
-        OpenGLCompatible = 0x0200,
-        NoFontMerging    = 0x8000
+        PreferDefault       = 0x0001,
+        PreferBitmap        = 0x0002,
+        PreferDevice        = 0x0004,
+        PreferOutline       = 0x0008,
+        ForceOutline        = 0x0010,
+        PreferMatch         = 0x0020,
+        PreferQuality       = 0x0040,
+        PreferAntialias     = 0x0080,
+        NoAntialias         = 0x0100,
+        OpenGLCompatible    = 0x0200,
+        ForceIntegerMetrics = 0x0400,
+        NoFontMerging       = 0x8000
     };
 
     enum Weight {
@@ -114,6 +119,38 @@ public:
         UltraExpanded  = 200
     };
 
+    enum Capitalization {
+        MixedCase,
+        AllUppercase,
+        AllLowercase,
+        SmallCaps,
+        Capitalize
+    };
+
+    enum SpacingType {
+        PercentageSpacing,
+        AbsoluteSpacing
+    };
+
+    enum ResolveProperties {
+        FamilyResolved         = 0x0001,
+        SizeResolved           = 0x0002,
+        StyleHintResolved      = 0x0004,
+        StyleStrategyResolved  = 0x0008,
+        WeightResolved         = 0x0010,
+        StyleResolved          = 0x0020,
+        UnderlineResolved      = 0x0040,
+        OverlineResolved       = 0x0080,
+        StrikeOutResolved      = 0x0100,
+        FixedPitchResolved     = 0x0200,
+        StretchResolved        = 0x0400,
+        KerningResolved        = 0x0800,
+        CapitalizationResolved = 0x1000,
+        LetterSpacingResolved  = 0x2000,
+        WordSpacingResolved    = 0x4000,
+        AllPropertiesResolved  = 0x7fff
+    };
+
     QFont();
     QFont(const QString &family, int pointSize = -1, int weight = -1, bool italic = false);
     QFont(const QFont &, QPaintDevice *pd);
@@ -166,6 +203,16 @@ public:
     int stretch() const;
     void setStretch(int);
 
+    qreal letterSpacing() const;
+    SpacingType letterSpacingType() const;
+    void setLetterSpacing(SpacingType type, qreal spacing);
+
+    qreal wordSpacing() const;
+    void setWordSpacing(qreal spacing);
+
+    void setCapitalization(Capitalization);
+    Capitalization capitalization() const;
+
     // is raw mode still needed?
     bool rawMode() const;
     void setRawMode(bool);
@@ -242,10 +289,13 @@ private:
     int x11Screen() const;
 #endif
 
+    friend class QFontPrivate;
+    friend class QFontDialogPrivate;
     friend class QFontMetrics;
     friend class QFontMetricsF;
     friend class QFontInfo;
     friend class QPainter;
+    friend class QPainterPrivate;
     friend class QPSPrintEngineFont;
     friend class QApplication;
     friend class QWidget;
@@ -262,13 +312,16 @@ private:
     friend class QPainterPath;
     friend class QTextItemInt;
     friend class QPicturePaintEngine;
+    friend class QPainterReplayer;
+    friend class QPaintBufferEngine;
+    friend class QCommandLinkButtonPrivate;
 
 #ifndef QT_NO_DATASTREAM
     friend Q_GUI_EXPORT QDataStream &operator<<(QDataStream &, const QFont &);
     friend Q_GUI_EXPORT QDataStream &operator>>(QDataStream &, QFont &);
 #endif
 
-    QFontPrivate *d;
+    QExplicitlySharedDataPointer<QFontPrivate> d;
     uint resolve_mask;
 };
 
@@ -299,6 +352,12 @@ Q_GUI_EXPORT QDataStream &operator<<(QDataStream &, const QFont &);
 Q_GUI_EXPORT QDataStream &operator>>(QDataStream &, QFont &);
 #endif
 
+#ifndef QT_NO_DEBUG_STREAM
+Q_GUI_EXPORT QDebug operator<<(QDebug, const QFont &);
+#endif
+
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QFONT_H
