@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -41,11 +46,16 @@
 #include <QtCore/qobject.h>
 #include <QtCore/qvariant.h>
 #include <QtCore/qrect.h>
+#include <QtCore/qscopedpointer.h>
 #include <QtGui/qpainterpath.h>
 #include <QtGui/qpixmap.h>
 
+class tst_QGraphicsItem;
+
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 #if !defined(QT_NO_GRAPHICSVIEW) || (QT_EDITION & QT_MODULE_GRAPHICSVIEW) != QT_MODULE_GRAPHICSVIEW
@@ -53,7 +63,9 @@ QT_MODULE(Gui)
 class QBrush;
 class QCursor;
 class QFocusEvent;
+class QGraphicsEffect;
 class QGraphicsItemGroup;
+class QGraphicsObject;
 class QGraphicsSceneContextMenuEvent;
 class QGraphicsSceneDragDropEvent;
 class QGraphicsSceneEvent;
@@ -61,6 +73,8 @@ class QGraphicsSceneHoverEvent;
 class QGraphicsSceneMouseEvent;
 class QGraphicsSceneWheelEvent;
 class QGraphicsScene;
+class QGraphicsTransform;
+class QGraphicsWidget;
 class QInputMethodEvent;
 class QKeyEvent;
 class QMatrix;
@@ -81,7 +95,20 @@ public:
         ItemIsFocusable = 0x4,
         ItemClipsToShape = 0x8,
         ItemClipsChildrenToShape = 0x10,
-        ItemIgnoresTransformations = 0x20
+        ItemIgnoresTransformations = 0x20,
+        ItemIgnoresParentOpacity = 0x40,
+        ItemDoesntPropagateOpacityToChildren = 0x80,
+        ItemStacksBehindParent = 0x100,
+        ItemUsesExtendedStyleOption = 0x200,
+        ItemHasNoContents = 0x400,
+        ItemSendsGeometryChanges = 0x800,
+        ItemAcceptsInputMethod = 0x1000,
+        ItemNegativeZStacksBehindParent = 0x2000,
+        ItemIsPanel = 0x4000,
+        ItemIsFocusScope = 0x8000, // internal
+        ItemSendsScenePositionChanges = 0x10000,
+        ItemStopsClickFocusPropagation = 0x20000
+        // NB! Don't forget to increase the d_ptr->flags bit field by 1 when adding a new flag.
     };
     Q_DECLARE_FLAGS(GraphicsItemFlags, GraphicsItemFlag)
 
@@ -97,12 +124,47 @@ public:
         ItemTransformChange,
         ItemPositionHasChanged,
         ItemTransformHasChanged,
-        ItemSceneChange
+        ItemSceneChange,
+        ItemVisibleHasChanged,
+        ItemEnabledHasChanged,
+        ItemSelectedHasChanged,
+        ItemParentHasChanged,
+        ItemSceneHasChanged,
+        ItemCursorChange,
+        ItemCursorHasChanged,
+        ItemToolTipChange,
+        ItemToolTipHasChanged,
+        ItemFlagsChange,
+        ItemFlagsHaveChanged,
+        ItemZValueChange,
+        ItemZValueHasChanged,
+        ItemOpacityChange,
+        ItemOpacityHasChanged,
+        ItemScenePositionHasChanged,
+        ItemRotationChange,
+        ItemRotationHasChanged,
+        ItemScaleChange,
+        ItemScaleHasChanged,
+        ItemTransformOriginPointChange,
+        ItemTransformOriginPointHasChanged
+    };
+
+    enum CacheMode {
+        NoCache,
+        ItemCoordinateCache,
+        DeviceCoordinateCache
+    };
+
+    enum PanelModality
+    {
+        NonModal,
+        PanelModal,
+        SceneModal
     };
 
     QGraphicsItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                  // obsolete argument
+                  // ### obsolete argument
                   , QGraphicsScene *scene = 0
 #endif
         );
@@ -112,8 +174,20 @@ public:
 
     QGraphicsItem *parentItem() const;
     QGraphicsItem *topLevelItem() const;
+    QGraphicsObject *parentObject() const;
+    QGraphicsWidget *parentWidget() const;
+    QGraphicsWidget *topLevelWidget() const;
+    QGraphicsWidget *window() const;
+    QGraphicsItem *panel() const;
     void setParentItem(QGraphicsItem *parent);
-    QList<QGraphicsItem *> children() const;
+    QList<QGraphicsItem *> children() const; // ### obsolete
+    QList<QGraphicsItem *> childItems() const;
+    bool isWidget() const;
+    bool isWindow() const;
+    bool isPanel() const;
+
+    QGraphicsObject *toGraphicsObject();
+    const QGraphicsObject *toGraphicsObject() const;
 
     QGraphicsItemGroup *group() const;
     void setGroup(QGraphicsItemGroup *group);
@@ -122,6 +196,13 @@ public:
     void setFlag(GraphicsItemFlag flag, bool enabled = true);
     void setFlags(GraphicsItemFlags flags);
 
+    CacheMode cacheMode() const;
+    void setCacheMode(CacheMode mode, const QSize &cacheSize = QSize());
+
+    PanelModality panelModality() const;
+    void setPanelModality(PanelModality panelModality);
+    bool isBlockedByModalPanel(QGraphicsItem **blockingPanel = 0) const;
+
 #ifndef QT_NO_TOOLTIP
     QString toolTip() const;
     void setToolTip(const QString &toolTip);
@@ -135,6 +216,7 @@ public:
 #endif
 
     bool isVisible() const;
+    bool isVisibleTo(const QGraphicsItem *parent) const;
     void setVisible(bool visible);
     inline void hide() { setVisible(false); }
     inline void show() { setVisible(true); }
@@ -148,23 +230,56 @@ public:
     bool acceptDrops() const;
     void setAcceptDrops(bool on);
 
+    qreal opacity() const;
+    qreal effectiveOpacity() const;
+    void setOpacity(qreal opacity);
+
+#ifndef QT_NO_GRAPHICSEFFECT
+    // Effect
+    QGraphicsEffect *graphicsEffect() const;
+    void setGraphicsEffect(QGraphicsEffect *effect);
+#endif //QT_NO_GRAPHICSEFFECT
+
     Qt::MouseButtons acceptedMouseButtons() const;
     void setAcceptedMouseButtons(Qt::MouseButtons buttons);
 
-    bool acceptsHoverEvents() const;
-    void setAcceptsHoverEvents(bool enabled);
+    bool acceptsHoverEvents() const; // ### obsolete
+    void setAcceptsHoverEvents(bool enabled); // ### obsolete
+    bool acceptHoverEvents() const;
+    void setAcceptHoverEvents(bool enabled);
+    bool acceptTouchEvents() const;
+    void setAcceptTouchEvents(bool enabled);
+
+    bool filtersChildEvents() const;
+    void setFiltersChildEvents(bool enabled);
 
     bool handlesChildEvents() const;
     void setHandlesChildEvents(bool enabled);
 
+    bool isActive() const;
+    void setActive(bool active);
+
     bool hasFocus() const;
     void setFocus(Qt::FocusReason focusReason = Qt::OtherFocusReason);
     void clearFocus();
 
+    QGraphicsItem *focusProxy() const;
+    void setFocusProxy(QGraphicsItem *item);
+
+    QGraphicsItem *focusItem() const;
+    QGraphicsItem *focusScopeItem() const;
+
+    void grabMouse();
+    void ungrabMouse();
+    void grabKeyboard();
+    void ungrabKeyboard();
+
     // Positioning in scene coordinates
     QPointF pos() const;
     inline qreal x() const { return pos().x(); }
+    void setX(qreal x);
     inline qreal y() const { return pos().y(); }
+    void setY(qreal y);
     QPointF scenePos() const;
     void setPos(const QPointF &pos);
     inline void setPos(qreal x, qreal y);
@@ -181,24 +296,43 @@ public:
     QTransform transform() const;
     QTransform sceneTransform() const;
     QTransform deviceTransform(const QTransform &viewportTransform) const;
+    QTransform itemTransform(const QGraphicsItem *other, bool *ok = 0) const;
     void setTransform(const QTransform &matrix, bool combine = false);
     void resetTransform();
-    
-    void rotate(qreal angle);
-    void scale(qreal sx, qreal sy);
-    void shear(qreal sh, qreal sv);
-    void translate(qreal dx, qreal dy);
+
+    void rotate(qreal angle);           // ### obsolete
+    void scale(qreal sx, qreal sy);     // ### obsolete
+    void shear(qreal sh, qreal sv);     // ### obsolete
+    void translate(qreal dx, qreal dy); // ### obsolete
+
+    void setRotation(qreal angle);
+    qreal rotation() const;
+
+    void setScale(qreal scale);
+    qreal scale() const;
+
+    QList<QGraphicsTransform *> transformations() const;
+    void setTransformations(const QList<QGraphicsTransform *> &transformations);
+
+    QPointF transformOriginPoint() const;
+    void setTransformOriginPoint(const QPointF &origin);
+    inline void setTransformOriginPoint(qreal ax, qreal ay)
+    { setTransformOriginPoint(QPointF(ax,ay)); }
+
     virtual void advance(int phase);
 
     // Stacking order
     qreal zValue() const;
     void setZValue(qreal z);
+    void stackBefore(const QGraphicsItem *sibling);
 
     // Hit test
     virtual QRectF boundingRect() const = 0;
     QRectF childrenBoundingRect() const;
     QRectF sceneBoundingRect() const;
     virtual QPainterPath shape() const;
+    bool isClipped() const;
+    QPainterPath clipPath() const;
     virtual bool contains(const QPointF &point) const;
     virtual bool collidesWithItem(const QGraphicsItem *other, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
     virtual bool collidesWithPath(const QPainterPath &path, Qt::ItemSelectionMode mode = Qt::IntersectsItemShape) const;
@@ -209,10 +343,15 @@ public:
     virtual bool isObscuredBy(const QGraphicsItem *item) const;
     virtual QPainterPath opaqueArea() const;
 
+    QRegion boundingRegion(const QTransform &itemToDeviceTransform) const;
+    qreal boundingRegionGranularity() const;
+    void setBoundingRegionGranularity(qreal granularity);
+
     // Drawing
     virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0) = 0;
     void update(const QRectF &rect = QRectF());
     inline void update(qreal x, qreal y, qreal width, qreal height);
+    void scroll(qreal dx, qreal dy, const QRectF &rect = QRectF());
 
     // Coordinate mapping
     QPointF mapToItem(const QGraphicsItem *item, const QPointF &point) const;
@@ -221,6 +360,9 @@ public:
     QPolygonF mapToItem(const QGraphicsItem *item, const QRectF &rect) const;
     QPolygonF mapToParent(const QRectF &rect) const;
     QPolygonF mapToScene(const QRectF &rect) const;
+    QRectF mapRectToItem(const QGraphicsItem *item, const QRectF &rect) const;
+    QRectF mapRectToParent(const QRectF &rect) const;
+    QRectF mapRectToScene(const QRectF &rect) const;
     QPolygonF mapToItem(const QGraphicsItem *item, const QPolygonF &polygon) const;
     QPolygonF mapToParent(const QPolygonF &polygon) const;
     QPolygonF mapToScene(const QPolygonF &polygon) const;
@@ -233,6 +375,9 @@ public:
     QPolygonF mapFromItem(const QGraphicsItem *item, const QRectF &rect) const;
     QPolygonF mapFromParent(const QRectF &rect) const;
     QPolygonF mapFromScene(const QRectF &rect) const;
+    QRectF mapRectFromItem(const QGraphicsItem *item, const QRectF &rect) const;
+    QRectF mapRectFromParent(const QRectF &rect) const;
+    QRectF mapRectFromScene(const QRectF &rect) const;
     QPolygonF mapFromItem(const QGraphicsItem *item, const QPolygonF &polygon) const;
     QPolygonF mapFromParent(const QPolygonF &polygon) const;
     QPolygonF mapFromScene(const QPolygonF &polygon) const;
@@ -246,19 +391,30 @@ public:
     inline QPolygonF mapToItem(const QGraphicsItem *item, qreal x, qreal y, qreal w, qreal h) const;
     inline QPolygonF mapToParent(qreal x, qreal y, qreal w, qreal h) const;
     inline QPolygonF mapToScene(qreal x, qreal y, qreal w, qreal h) const;
+    inline QRectF mapRectToItem(const QGraphicsItem *item, qreal x, qreal y, qreal w, qreal h) const;
+    inline QRectF mapRectToParent(qreal x, qreal y, qreal w, qreal h) const;
+    inline QRectF mapRectToScene(qreal x, qreal y, qreal w, qreal h) const;
     inline QPointF mapFromItem(const QGraphicsItem *item, qreal x, qreal y) const;
     inline QPointF mapFromParent(qreal x, qreal y) const;
     inline QPointF mapFromScene(qreal x, qreal y) const;
     inline QPolygonF mapFromItem(const QGraphicsItem *item, qreal x, qreal y, qreal w, qreal h) const;
     inline QPolygonF mapFromParent(qreal x, qreal y, qreal w, qreal h) const;
     inline QPolygonF mapFromScene(qreal x, qreal y, qreal w, qreal h) const;
+    inline QRectF mapRectFromItem(const QGraphicsItem *item, qreal x, qreal y, qreal w, qreal h) const;
+    inline QRectF mapRectFromParent(qreal x, qreal y, qreal w, qreal h) const;
+    inline QRectF mapRectFromScene(qreal x, qreal y, qreal w, qreal h) const;
 
     bool isAncestorOf(const QGraphicsItem *child) const;
+    QGraphicsItem *commonAncestorItem(const QGraphicsItem *other) const;
+    bool isUnderMouse() const;
 
     // Custom data
     QVariant data(int key) const;
     void setData(int key, const QVariant &value);
 
+    Qt::InputMethodHints inputMethodHints() const;
+    void setInputMethodHints(Qt::InputMethodHints hints);
+
     enum {
         Type = 1,
         UserType = 65536
@@ -269,6 +425,7 @@ public:
     void removeSceneEventFilter(QGraphicsItem *filterItem);
 
 protected:
+    void updateMicroFocus();
     virtual bool sceneEventFilter(QGraphicsItem *watched, QEvent *event);
     virtual bool sceneEvent(QEvent *event);
     virtual void contextMenuEvent(QGraphicsSceneContextMenuEvent *event);
@@ -303,7 +460,7 @@ protected:
 protected:
     QGraphicsItem(QGraphicsItemPrivate &dd,
                   QGraphicsItem *parent, QGraphicsScene *scene);
-    QGraphicsItemPrivate *d_ptr;
+    QScopedPointer<QGraphicsItemPrivate> d_ptr;
 
     void addToIndex();
     void removeFromIndex();
@@ -316,16 +473,29 @@ private:
     friend class QGraphicsScene;
     friend class QGraphicsScenePrivate;
     friend class QGraphicsSceneFindItemBspTreeVisitor;
+    friend class QGraphicsSceneBspTree;
     friend class QGraphicsView;
     friend class QGraphicsViewPrivate;
-    friend class tst_QGraphicsItem;
+    friend class QGraphicsObject;
+    friend class QGraphicsWidget;
+    friend class QGraphicsWidgetPrivate;
+    friend class QGraphicsProxyWidgetPrivate;
+    friend class QGraphicsSceneIndex;
+    friend class QGraphicsSceneIndexPrivate;
+    friend class QGraphicsSceneBspTreeIndex;
+    friend class QGraphicsSceneBspTreeIndexPrivate;
+    friend class QGraphicsItemEffectSourcePrivate;
+    friend class QGraphicsTransformPrivate;
+#ifndef QT_NO_GESTURES
+    friend class QGestureManager;
+#endif
+    friend class ::tst_QGraphicsItem;
     friend bool qt_closestLeaf(const QGraphicsItem *, const QGraphicsItem *);
     friend bool qt_closestItemFirst(const QGraphicsItem *, const QGraphicsItem *);
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(QGraphicsItem::GraphicsItemFlags)
-Q_DECLARE_METATYPE(QGraphicsItem *)
-Q_DECLARE_METATYPE(QGraphicsScene *)
+Q_DECLARE_INTERFACE(QGraphicsItem, "com.trolltech.Qt.QGraphicsItem")
 
 inline void QGraphicsItem::setPos(qreal ax, qreal ay)
 { setPos(QPointF(ax, ay)); }
@@ -353,12 +523,87 @@ inline QPolygonF QGraphicsItem::mapToParent(qreal ax, qreal ay, qreal w, qreal h
 { return mapToParent(QRectF(ax, ay, w, h)); }
 inline QPolygonF QGraphicsItem::mapToScene(qreal ax, qreal ay, qreal w, qreal h) const
 { return mapToScene(QRectF(ax, ay, w, h)); }
+inline QRectF QGraphicsItem::mapRectToItem(const QGraphicsItem *item, qreal ax, qreal ay, qreal w, qreal h) const
+{ return mapRectToItem(item, QRectF(ax, ay, w, h)); }
+inline QRectF QGraphicsItem::mapRectToParent(qreal ax, qreal ay, qreal w, qreal h) const
+{ return mapRectToParent(QRectF(ax, ay, w, h)); }
+inline QRectF QGraphicsItem::mapRectToScene(qreal ax, qreal ay, qreal w, qreal h) const
+{ return mapRectToScene(QRectF(ax, ay, w, h)); }
 inline QPolygonF QGraphicsItem::mapFromItem(const QGraphicsItem *item, qreal ax, qreal ay, qreal w, qreal h) const
 { return mapFromItem(item, QRectF(ax, ay, w, h)); }
 inline QPolygonF QGraphicsItem::mapFromParent(qreal ax, qreal ay, qreal w, qreal h) const
 { return mapFromParent(QRectF(ax, ay, w, h)); }
 inline QPolygonF QGraphicsItem::mapFromScene(qreal ax, qreal ay, qreal w, qreal h) const
 { return mapFromScene(QRectF(ax, ay, w, h)); }
+inline QRectF QGraphicsItem::mapRectFromItem(const QGraphicsItem *item, qreal ax, qreal ay, qreal w, qreal h) const
+{ return mapRectFromItem(item, QRectF(ax, ay, w, h)); }
+inline QRectF QGraphicsItem::mapRectFromParent(qreal ax, qreal ay, qreal w, qreal h) const
+{ return mapRectFromParent(QRectF(ax, ay, w, h)); }
+inline QRectF QGraphicsItem::mapRectFromScene(qreal ax, qreal ay, qreal w, qreal h) const
+{ return mapRectFromScene(QRectF(ax, ay, w, h)); }
+
+
+class Q_GUI_EXPORT QGraphicsObject : public QObject, public QGraphicsItem
+{
+    Q_OBJECT
+    Q_PROPERTY(QGraphicsObject * parent READ parentObject WRITE setParentItem NOTIFY parentChanged DESIGNABLE false)
+    Q_PROPERTY(qreal opacity READ opacity WRITE setOpacity NOTIFY opacityChanged FINAL)
+    Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
+    Q_PROPERTY(bool visible READ isVisible WRITE setVisible NOTIFY visibleChanged FINAL)
+    Q_PROPERTY(QPointF pos READ pos WRITE setPos FINAL)
+    Q_PROPERTY(qreal x READ x WRITE setX NOTIFY xChanged FINAL)
+    Q_PROPERTY(qreal y READ y WRITE setY NOTIFY yChanged FINAL)
+    Q_PROPERTY(qreal z READ zValue WRITE setZValue NOTIFY zChanged FINAL)
+    Q_PROPERTY(qreal rotation READ rotation WRITE setRotation NOTIFY rotationChanged)
+    Q_PROPERTY(qreal scale READ scale WRITE setScale NOTIFY scaleChanged)
+    Q_PROPERTY(QPointF transformOriginPoint READ transformOriginPoint WRITE setTransformOriginPoint)
+#ifndef QT_NO_GRAPHICSEFFECT
+    Q_PROPERTY(QGraphicsEffect *effect READ graphicsEffect WRITE setGraphicsEffect)
+#endif
+    Q_PRIVATE_PROPERTY(QGraphicsItem::d_func(), QDeclarativeListProperty<QGraphicsObject> children READ childrenList DESIGNABLE false NOTIFY childrenChanged)
+    Q_PRIVATE_PROPERTY(QGraphicsItem::d_func(), qreal width READ width WRITE setWidth NOTIFY widthChanged RESET resetWidth FINAL)
+    Q_PRIVATE_PROPERTY(QGraphicsItem::d_func(), qreal height READ height WRITE setHeight NOTIFY heightChanged RESET resetHeight FINAL)
+    Q_CLASSINFO("DefaultProperty", "children")
+    Q_INTERFACES(QGraphicsItem)
+public:
+    QGraphicsObject(QGraphicsItem *parent = 0);
+
+    // ### Qt 5: Disambiguate
+#ifdef Q_NO_USING_KEYWORD
+    const QObjectList &children() const { return QObject::children(); }
+#else
+    using QObject::children;
+#endif
+
+#ifndef QT_NO_GESTURES
+    void grabGesture(Qt::GestureType type, Qt::GestureFlags flags = Qt::GestureFlags());
+    void ungrabGesture(Qt::GestureType type);
+#endif
+
+protected Q_SLOTS:
+    void updateMicroFocus();
+
+Q_SIGNALS:
+    void parentChanged();
+    void opacityChanged();
+    void visibleChanged();
+    void enabledChanged();
+    void xChanged();
+    void yChanged();
+    void zChanged();
+    void rotationChanged();
+    void scaleChanged();
+    void childrenChanged();
+    void widthChanged();
+    void heightChanged();
+
+protected:
+    QGraphicsObject(QGraphicsItemPrivate &dd, QGraphicsItem *parent, QGraphicsScene *scene);
+private:
+    friend class QGraphicsItem;
+    friend class QGraphicsItemPrivate;
+};
+
 
 class QAbstractGraphicsShapeItemPrivate;
 class Q_GUI_EXPORT QAbstractGraphicsShapeItem : public QGraphicsItem
@@ -366,7 +611,7 @@ class Q_GUI_EXPORT QAbstractGraphicsShapeItem : public QGraphicsItem
 public:
     QAbstractGraphicsShapeItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                               // obsolete argument
+                               // ### obsolete argument
                                , QGraphicsScene *scene = 0
 #endif
         );
@@ -396,13 +641,13 @@ class Q_GUI_EXPORT QGraphicsPathItem : public QAbstractGraphicsShapeItem
 public:
     QGraphicsPathItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsPathItem(const QPainterPath &path, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
@@ -439,19 +684,19 @@ class Q_GUI_EXPORT QGraphicsRectItem : public QAbstractGraphicsShapeItem
 public:
     QGraphicsRectItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsRectItem(const QRectF &rect, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsRectItem(qreal x, qreal y, qreal w, qreal h, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
@@ -492,19 +737,19 @@ class Q_GUI_EXPORT QGraphicsEllipseItem : public QAbstractGraphicsShapeItem
 public:
     QGraphicsEllipseItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                         // obsolete argument
+                         // ### obsolete argument
                          , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsEllipseItem(const QRectF &rect, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                         // obsolete argument
+                         // ### obsolete argument
                          , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsEllipseItem(qreal x, qreal y, qreal w, qreal h, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                         // obsolete argument
+                         // ### obsolete argument
                          , QGraphicsScene *scene = 0
 #endif
         );
@@ -551,14 +796,14 @@ class Q_GUI_EXPORT QGraphicsPolygonItem : public QAbstractGraphicsShapeItem
 public:
     QGraphicsPolygonItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                         // obsolete argument
+                         // ### obsolete argument
                          , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsPolygonItem(const QPolygonF &polygon,
                          QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                         // obsolete argument
+                         // ### obsolete argument
                          , QGraphicsScene *scene = 0
 #endif
         );
@@ -598,19 +843,19 @@ class Q_GUI_EXPORT QGraphicsLineItem : public QGraphicsItem
 public:
     QGraphicsLineItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsLineItem(const QLineF &line, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsLineItem(qreal x1, qreal y1, qreal x2, qreal y2, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
@@ -658,13 +903,13 @@ public:
 
     QGraphicsPixmapItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                        // obsolete argument
+                        // ### obsolete argument
                         , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsPixmapItem(const QPixmap &pixmap, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                        // obsolete argument
+                        // ### obsolete argument
                         , QGraphicsScene *scene = 0
 #endif
         );
@@ -711,7 +956,7 @@ inline void QGraphicsPixmapItem::setOffset(qreal ax, qreal ay)
 class QGraphicsTextItemPrivate;
 class QTextDocument;
 class QTextCursor;
-class Q_GUI_EXPORT QGraphicsTextItem : public QObject, public QGraphicsItem
+class Q_GUI_EXPORT QGraphicsTextItem : public QGraphicsObject
 {
     Q_OBJECT
     QDOC_PROPERTY(bool openExternalLinks READ openExternalLinks WRITE setOpenExternalLinks)
@@ -720,13 +965,13 @@ class Q_GUI_EXPORT QGraphicsTextItem : public QObject, public QGraphicsItem
 public:
     QGraphicsTextItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsTextItem(const QString &text, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                      // obsolete argument
+                      // ### obsolete argument
                       , QGraphicsScene *scene = 0
 #endif
         );
@@ -767,6 +1012,9 @@ public:
     void setTextInteractionFlags(Qt::TextInteractionFlags flags);
     Qt::TextInteractionFlags textInteractionFlags() const;
 
+    void setTabChangesFocus(bool b);
+    bool tabChangesFocus() const;
+
     void setOpenExternalLinks(bool open);
     bool openExternalLinks() const;
 
@@ -818,13 +1066,13 @@ class Q_GUI_EXPORT QGraphicsSimpleTextItem : public QAbstractGraphicsShapeItem
 public:
     QGraphicsSimpleTextItem(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                            // obsolete argument
+                            // ### obsolete argument
                             , QGraphicsScene *scene = 0
 #endif
         );
     QGraphicsSimpleTextItem(const QString &text, QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                            // obsolete argument
+                            // ### obsolete argument
                             , QGraphicsScene *scene = 0
 #endif
         );
@@ -864,7 +1112,7 @@ class Q_GUI_EXPORT QGraphicsItemGroup : public QGraphicsItem
 public:
     QGraphicsItemGroup(QGraphicsItem *parent = 0
 #ifndef Q_QDOC
-                       // obsolete argument
+                       // ### obsolete argument
                        , QGraphicsScene *scene = 0
 #endif
         );
@@ -901,10 +1149,23 @@ template <class T> inline T qgraphicsitem_cast(const QGraphicsItem *item)
 
 #ifndef QT_NO_DEBUG_STREAM
 Q_GUI_EXPORT QDebug operator<<(QDebug debug, QGraphicsItem *item);
+Q_GUI_EXPORT QDebug operator<<(QDebug debug, QGraphicsObject *item);
+Q_GUI_EXPORT QDebug operator<<(QDebug debug, QGraphicsItem::GraphicsItemChange change);
+Q_GUI_EXPORT QDebug operator<<(QDebug debug, QGraphicsItem::GraphicsItemFlag flag);
+Q_GUI_EXPORT QDebug operator<<(QDebug debug, QGraphicsItem::GraphicsItemFlags flags);
 #endif
 
+QT_END_NAMESPACE
+
+Q_DECLARE_METATYPE(QGraphicsItem *)
+Q_DECLARE_METATYPE(QGraphicsScene *)
+
+QT_BEGIN_NAMESPACE
+
+#endif // QT_NO_GRAPHICSVIEW
+
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
-#endif
-
-#endif // QT_NO_GRAPHICSVIEW
+#endif // QGRAPHICSITEM_H
