@@ -1,47 +1,55 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #ifndef QPRINTER_H
 #define QPRINTER_H
 
-#include <QtGui/qpaintdevice.h>
 #include <QtCore/qstring.h>
+#include <QtCore/qscopedpointer.h>
+#include <QtGui/qpaintdevice.h>
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_PRINTER
@@ -53,6 +61,7 @@ QT_MODULE(Gui)
 class QPrinterPrivate;
 class QPaintEngine;
 class QPrintEngine;
+class QPrinterInfo;
 
 class Q_GUI_EXPORT QPrinter : public QPaintDevice
 {
@@ -61,36 +70,49 @@ public:
     enum PrinterMode { ScreenResolution, PrinterResolution, HighResolution };
 
     explicit QPrinter(PrinterMode mode = ScreenResolution);
+    explicit QPrinter(const QPrinterInfo& printer, PrinterMode mode = ScreenResolution);
     ~QPrinter();
 
     int devType() const;
 
     enum Orientation { Portrait, Landscape };
 
-    enum PageSize    { A4, B5, Letter, Legal, Executive,
-		       A0, A1, A2, A3, A5, A6, A7, A8, A9, B0, B1,
-		       B10, B2, B3, B4, B6, B7, B8, B9, C5E, Comm10E,
-		       DLE, Folio, Ledger, Tabloid, Custom, NPageSize = Custom };
+#ifndef Q_QDOC
+    enum PageSize { A4, B5, Letter, Legal, Executive,
+                    A0, A1, A2, A3, A5, A6, A7, A8, A9, B0, B1,
+                    B10, B2, B3, B4, B6, B7, B8, B9, C5E, Comm10E,
+                    DLE, Folio, Ledger, Tabloid, Custom, NPageSize = Custom, NPaperSize = Custom };
+    typedef PageSize PaperSize;
+#else
+    enum PageSize { A4, B5, Letter, Legal, Executive,
+                    A0, A1, A2, A3, A5, A6, A7, A8, A9, B0, B1,
+                    B10, B2, B3, B4, B6, B7, B8, B9, C5E, Comm10E,
+                    DLE, Folio, Ledger, Tabloid, Custom, NPageSize = Custom };
+    enum PaperSize { A4, B5, Letter, Legal, Executive,
+                     A0, A1, A2, A3, A5, A6, A7, A8, A9, B0, B1,
+                     B10, B2, B3, B4, B6, B7, B8, B9, C5E, Comm10E,
+                     DLE, Folio, Ledger, Tabloid, Custom, NPageSize = Custom, NPaperSize = Custom };
+#endif
 
     enum PageOrder   { FirstPageFirst,
-		       LastPageFirst };
+                       LastPageFirst };
 
     enum ColorMode   { GrayScale,
-		       Color };
+                       Color };
 
     enum PaperSource { OnlyOne,
-		       Lower,
-		       Middle,
-		       Manual,
-		       Envelope,
+                       Lower,
+                       Middle,
+                       Manual,
+                       Envelope,
                        EnvelopeManual,
-		       Auto,
-		       Tractor,
-		       SmallFormat,
+                       Auto,
+                       Tractor,
+                       SmallFormat,
                        LargeFormat,
-		       LargeCapacity,
-		       Cassette,
-		       FormSource,
+                       LargeCapacity,
+                       Cassette,
+                       FormSource,
                        MaxPageSource
     };
 
@@ -102,7 +124,24 @@ public:
     enum OutputFormat { NativeFormat, PdfFormat, PostScriptFormat };
 
     // ### Qt 5: Merge with QAbstractPrintDialog::PrintRange
-    enum PrintRange { AllPages, Selection, PageRange };
+    enum PrintRange { AllPages, Selection, PageRange, CurrentPage };
+
+    enum Unit {
+        Millimeter,
+        Point,
+        Inch,
+        Pica,
+        Didot,
+        Cicero,
+        DevicePixel
+    };
+
+    enum DuplexMode {
+        DuplexNone = 0,
+        DuplexAuto,
+        DuplexLongSide,
+        DuplexShortSide
+    };
 
 #ifdef QT3_SUPPORT
     enum PrinterOption { PrintToFile, PrintSelection, PrintPageRange };
@@ -114,6 +153,8 @@ public:
     void setPrinterName(const QString &);
     QString printerName() const;
 
+    bool isValid() const;
+
     void setOutputFileName(const QString &);
     QString outputFileName()const;
 
@@ -132,6 +173,12 @@ public:
     void setPageSize(PageSize);
     PageSize pageSize() const;
 
+    void setPaperSize(PaperSize);
+    PaperSize paperSize() const;
+
+    void setPaperSize(const QSizeF &paperSize, Unit unit);
+    QSizeF paperSize(Unit unit) const;
+
     void setPageOrder(PageOrder);
     PageOrder pageOrder() const;
 
@@ -150,9 +197,18 @@ public:
     void setNumCopies(int);
     int numCopies() const;
 
+    int actualNumCopies() const;
+
+    void setCopyCount(int);
+    int copyCount() const;
+    bool supportsMultipleCopies() const;
+
     void setPaperSource(PaperSource);
     PaperSource paperSource() const;
 
+    void setDuplex(DuplexMode duplex);
+    DuplexMode duplex() const;
+
     QList<int> supportedResolutions() const;
 
 #ifdef Q_WS_WIN
@@ -172,6 +228,8 @@ public:
 
     QRect paperRect() const;
     QRect pageRect() const;
+    QRectF paperRect(Unit) const;
+    QRectF pageRect(Unit) const;
 
 #if !defined(Q_WS_WIN) || defined(qdoc)
     QString printerSelectionOption() const;
@@ -198,6 +256,9 @@ public:
     void setPrintRange(PrintRange range);
     PrintRange printRange() const;
 
+    void setPageMargins(qreal left, qreal top, qreal right, qreal bottom, Unit unit);
+    void getPageMargins(qreal *left, qreal *top, qreal *right, qreal *bottom, Unit unit) const;
+
 #ifdef QT3_SUPPORT
 #ifdef Q_WS_MAC
     QT3_SUPPORT bool pageSetup(QWidget *parent = 0);
@@ -230,12 +291,18 @@ protected:
     void setEngines(QPrintEngine *printEngine, QPaintEngine *paintEngine);
 
 private:
+    void init(PrinterMode mode);
+
     Q_DISABLE_COPY(QPrinter)
 
-    QPrinterPrivate *d_ptr;
+    QScopedPointer<QPrinterPrivate> d_ptr;
 
-    friend class QPrintDialogWin;
+    friend class QPrintDialogPrivate;
     friend class QAbstractPrintDialog;
+    friend class QAbstractPrintDialogPrivate;
+    friend class QPrintPreviewWidgetPrivate;
+    friend class QTextDocument;
+    friend class QPageSetupWidget;
 };
 
 #ifdef QT3_SUPPORT
@@ -263,6 +330,8 @@ inline void QPrinter::margins(uint *top, uint *left, uint *bottom, uint *right)
 
 #endif // QT_NO_PRINTER
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QPRINTER_H
