@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -28,6 +46,8 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_SPINBOX
@@ -40,26 +60,26 @@ class Q_GUI_EXPORT QSpinBox : public QAbstractSpinBox
     Q_PROPERTY(QString suffix READ suffix WRITE setSuffix)
     Q_PROPERTY(QString prefix READ prefix WRITE setPrefix)
     Q_PROPERTY(QString cleanText READ cleanText)
-    Q_PROPERTY(int maximum READ maximum WRITE setMaximum)
     Q_PROPERTY(int minimum READ minimum WRITE setMinimum)
+    Q_PROPERTY(int maximum READ maximum WRITE setMaximum)
     Q_PROPERTY(int singleStep READ singleStep WRITE setSingleStep)
     Q_PROPERTY(int value READ value WRITE setValue NOTIFY valueChanged USER true)
 
 public:
     explicit QSpinBox(QWidget *parent = 0);
-#ifdef QT_COMPAT
-    QT_COMPAT_CONSTRUCTOR QSpinBox(QWidget *parent, const char *name);
-    QT_COMPAT_CONSTRUCTOR QSpinBox(int min, int max, int step, QWidget *parent,
-                                   const char *name = 0);
+#ifdef QT3_SUPPORT
+    QT3_SUPPORT_CONSTRUCTOR QSpinBox(QWidget *parent, const char *name);
+    QT3_SUPPORT_CONSTRUCTOR QSpinBox(int min, int max, int step, QWidget *parent,
+                                     const char *name = 0);
 #endif
 
     int value() const;
 
     QString prefix() const;
-    void setPrefix(const QString &p);
+    void setPrefix(const QString &prefix);
 
     QString suffix() const;
-    void setSuffix(const QString &s);
+    void setSuffix(const QString &suffix);
 
     QString cleanText() const;
 
@@ -74,19 +94,19 @@ public:
 
     void setRange(int min, int max);
 
-#ifdef QT_COMPAT
-    inline QT_COMPAT void setLineStep(int step) { setSingleStep(step); }
-    inline QT_COMPAT void setMaxValue(int val) { setMaximum(val); }
-    inline QT_COMPAT void setMinValue(int val) { setMinimum(val); }
-    inline QT_COMPAT int maxValue() const { return maximum(); }
-    inline QT_COMPAT int minValue() const { return minimum(); }
+#ifdef QT3_SUPPORT
+    inline QT3_SUPPORT void setLineStep(int step) { setSingleStep(step); }
+    inline QT3_SUPPORT void setMaxValue(int val) { setMaximum(val); }
+    inline QT3_SUPPORT void setMinValue(int val) { setMinimum(val); }
+    inline QT3_SUPPORT int maxValue() const { return maximum(); }
+    inline QT3_SUPPORT int minValue() const { return minimum(); }
 #endif
 
 protected:
-    bool event(QEvent *e);
+    bool event(QEvent *event);
     virtual QValidator::State validate(QString &input, int &pos) const;
     virtual int valueFromText(const QString &text) const;
-    virtual QString textFromValue(int v) const;
+    virtual QString textFromValue(int val) const;
     virtual void fixup(QString &str) const;
 
 
@@ -111,20 +131,20 @@ class Q_GUI_EXPORT QDoubleSpinBox : public QAbstractSpinBox
     Q_PROPERTY(QString suffix READ suffix WRITE setSuffix)
     Q_PROPERTY(QString cleanText READ cleanText)
     Q_PROPERTY(int decimals READ decimals WRITE setDecimals)
-    Q_PROPERTY(double maximum READ maximum WRITE setMaximum)
     Q_PROPERTY(double minimum READ minimum WRITE setMinimum)
+    Q_PROPERTY(double maximum READ maximum WRITE setMaximum)
     Q_PROPERTY(double singleStep READ singleStep WRITE setSingleStep)
-    Q_PROPERTY(double value READ value WRITE setValue NOTIFY valueChanged)
+    Q_PROPERTY(double value READ value WRITE setValue NOTIFY valueChanged USER true)
 public:
     explicit QDoubleSpinBox(QWidget *parent = 0);
 
     double value() const;
 
     QString prefix() const;
-    void setPrefix(const QString &p);
+    void setPrefix(const QString &prefix);
 
     QString suffix() const;
-    void setSuffix(const QString &s);
+    void setSuffix(const QString &suffix);
 
     QString cleanText() const;
 
@@ -144,7 +164,7 @@ public:
 
     virtual QValidator::State validate(QString &input, int &pos) const;
     virtual double valueFromText(const QString &text) const;
-    virtual QString textFromValue(double v) const;
+    virtual QString textFromValue(double val) const;
     virtual void fixup(QString &str) const;
 
 public Q_SLOTS:
@@ -161,6 +181,8 @@ private:
 
 #endif // QT_NO_SPINBOX
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QSPINBOX_H
