@@ -26,11 +26,7 @@
 #define QT_LARGEFILE_SUPPORT 64
 #define QT_POINTER_SIZE 4
 
-#if defined(QT_BUILTIN_GIF_READER) && defined(QT_NO_BUILTIN_GIF_READER)
-# undef QT_BUILTIN_GIF_READER
-#elif !defined(QT_BUILTIN_GIF_READER) && !defined(QT_NO_BUILTIN_GIF_READER)
-# define QT_BUILTIN_GIF_READER 1
-#endif
+#ifndef QT_BOOTSTRAPPED
 
 #if defined(QT_NO_ALSA) && defined(QT_ALSA)
 # undef QT_NO_ALSA
@@ -44,18 +40,24 @@
 # define QT_NO_CLOCK_MONOTONIC
 #endif
 
-#if defined(QT_NO_DECLARATIVE) && defined(QT_DECLARATIVE)
-# undef QT_NO_DECLARATIVE
-#elif !defined(QT_NO_DECLARATIVE) && !defined(QT_DECLARATIVE)
-# define QT_NO_DECLARATIVE
-#endif
-
 #if defined(QT_NO_EGL) && defined(QT_EGL)
 # undef QT_NO_EGL
 #elif !defined(QT_NO_EGL) && !defined(QT_EGL)
 # define QT_NO_EGL
 #endif
 
+#if defined(QT_NO_GUI) && defined(QT_GUI)
+# undef QT_NO_GUI
+#elif !defined(QT_NO_GUI) && !defined(QT_GUI)
+# define QT_NO_GUI
+#endif
+
+#if defined(QT_NO_ICD) && defined(QT_ICD)
+# undef QT_NO_ICD
+#elif !defined(QT_NO_ICD) && !defined(QT_ICD)
+# define QT_NO_ICD
+#endif
+
 #if defined(QT_NO_ICONV) && defined(QT_ICONV)
 # undef QT_NO_ICONV
 #elif !defined(QT_NO_ICONV) && !defined(QT_ICONV)
@@ -104,6 +106,24 @@
 # define QT_NO_OPENVG
 #endif
 
+#if defined(QT_NO_PULSEAUDIO) && defined(QT_PULSEAUDIO)
+# undef QT_NO_PULSEAUDIO
+#elif !defined(QT_NO_PULSEAUDIO) && !defined(QT_PULSEAUDIO)
+# define QT_NO_PULSEAUDIO
+#endif
+
+#if defined(QT_NO_S60) && defined(QT_S60)
+# undef QT_NO_S60
+#elif !defined(QT_NO_S60) && !defined(QT_S60)
+# define QT_NO_S60
+#endif
+
+#if defined(QT_NO_STYLE_S60) && defined(QT_STYLE_S60)
+# undef QT_NO_STYLE_S60
+#elif !defined(QT_NO_STYLE_S60) && !defined(QT_STYLE_S60)
+# define QT_NO_STYLE_S60
+#endif
+
 #if defined(QT_NO_SXE) && defined(QT_SXE)
 # undef QT_NO_SXE
 #elif !defined(QT_NO_SXE) && !defined(QT_SXE)
@@ -140,5 +160,7 @@
 # define QT_USE_MATH_H_FLOATS
 #endif
 
+#endif // QT_BOOTSTRAPPED
+
 #define QT_VISIBILITY_AVAILABLE
 
