@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -192,6 +192,8 @@ public:
     QPointF(const QPoint &p);
     QPointF(qreal xpos, qreal ypos);
 
+    qreal manhattanLength() const;
+
     bool isNull() const;
 
     qreal x() const;
@@ -300,12 +302,12 @@ inline QPointF &QPointF::operator*=(qreal c)
 
 inline bool operator==(const QPointF &p1, const QPointF &p2)
 {
-    return qFuzzyCompare(p1.xp, p2.xp) && qFuzzyCompare(p1.yp, p2.yp);
+    return qFuzzyIsNull(p1.xp - p2.xp) && qFuzzyIsNull(p1.yp - p2.yp);
 }
 
 inline bool operator!=(const QPointF &p1, const QPointF &p2)
 {
-    return !qFuzzyCompare(p1.xp, p2.xp) || !qFuzzyCompare(p1.yp, p2.yp);
+    return !qFuzzyIsNull(p1.xp - p2.xp) || !qFuzzyIsNull(p1.yp - p2.yp);
 }
 
 inline const QPointF operator+(const QPointF &p1, const QPointF &p2)
