@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the tools applications of the Qt Toolkit.
+** This file is part of the QtDBus module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -51,11 +49,17 @@
 #include <QtDBus/qdbusmessage.h>
 #include <QtDBus/qdbuserror.h>
 #include <QtDBus/qdbusextratypes.h>
+#include <QtDBus/qdbuspendingreply.h>
+
+#ifndef QT_NO_DBUS
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
 
-QDBUS_EXPORT void qDBusReplyFill(const QDBusMessage &reply, QDBusError &error, QVariant &data);
+QT_MODULE(DBus)
+
+Q_DBUS_EXPORT void qDBusReplyFill(const QDBusMessage &reply, QDBusError &error, QVariant &data);
 
 template<typename T>
 class QDBusReply
@@ -74,6 +78,21 @@ public:
         return *this;
     }
 
+    inline QDBusReply(const QDBusPendingCall &pcall)
+    {
+        *this = pcall;
+    }
+    inline QDBusReply &operator=(const QDBusPendingCall &pcall)
+    {
+        QDBusPendingCall other(pcall);
+        other.waitForFinished();
+        return *this = other.reply();
+    }
+    inline QDBusReply(const QDBusPendingReply<T> &reply)
+    {
+        *this = static_cast<QDBusPendingCall>(reply);
+    }
+
     inline QDBusReply(const QDBusError &dbusError = QDBusError())
         : m_error(dbusError), m_data(Type())
     {
@@ -132,10 +151,36 @@ public:
         : m_error(reply)
     {
     }
-    inline QDBusReply(const QDBusError &dbusError)
+    inline QDBusReply& operator=(const QDBusMessage &reply)
+    {
+        m_error = reply;
+        return *this;
+    }
+    inline QDBusReply(const QDBusError &dbusError = QDBusError())
         : m_error(dbusError)
     {
     }
+    inline QDBusReply(const QDBusPendingCall &pcall)
+    {
+        *this = pcall;
+    }
+    inline QDBusReply &operator=(const QDBusPendingCall &pcall)
+    {
+        QDBusPendingCall other(pcall);
+        other.waitForFinished();
+        return *this = other.reply();
+    }
+    inline QDBusReply& operator=(const QDBusError& dbusError)
+    {
+        m_error = dbusError;
+        return *this;
+    }
+
+    inline QDBusReply& operator=(const QDBusReply& other)
+    {
+        m_error = other.m_error;
+        return *this;
+    }
 
     inline bool isValid() const { return !m_error.isValid(); }
 
@@ -146,6 +191,9 @@ private:
 };
 # endif
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
+#endif // QT_NO_DBUS
 #endif
