@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -44,6 +44,10 @@
 
 #include <QtGui/qpixmap.h>
 
+#ifdef Q_TEST_QPIXMAPCACHE
+#include <QtCore/qpair.h>
+#endif
+
 QT_BEGIN_HEADER
 
 QT_BEGIN_NAMESPACE
@@ -53,13 +57,42 @@ QT_MODULE(Gui)
 class Q_GUI_EXPORT QPixmapCache
 {
 public:
+    class KeyData;
+    class Q_GUI_EXPORT Key
+    {
+    public:
+        Key();
+        Key(const Key &other);
+        ~Key();
+        bool operator ==(const Key &key) const;
+        inline bool operator !=(const Key &key) const
+        { return !operator==(key); }
+        Key &operator =(const Key &other);
+
+    private:
+        KeyData *d;
+        friend class QPMCache;
+        friend class QPixmapCache;
+    };
+
     static int cacheLimit();
     static void setCacheLimit(int);
     static QPixmap *find(const QString &key);
-    static bool find(const QString &key, QPixmap&);
-    static bool insert(const QString &key, const QPixmap&);
+    static bool find(const QString &key, QPixmap &pixmap);
+    static bool find(const QString &key, QPixmap *pixmap);
+    static bool find(const Key &key, QPixmap *pixmap);
+    static bool insert(const QString &key, const QPixmap &pixmap);
+    static Key insert(const QPixmap &pixmap);
+    static bool replace(const Key &key, const QPixmap &pixmap);
     static void remove(const QString &key);
+    static void remove(const Key &key);
     static void clear();
+
+#ifdef Q_TEST_QPIXMAPCACHE
+    static void flushDetachedPixmaps();
+    static int totalUsed();
+    static QList< QPair<QString,QPixmap> > allPixmaps();
+#endif
 };
 
 QT_END_NAMESPACE
