@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -41,14 +46,20 @@
 #include <QtCore/qrect.h>
 #include <QtGui/qwindowdefs.h>
 
+#ifndef QT_NO_DATASTREAM
+#include <QtCore/qdatastream.h>
+#endif
+
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 template <class T> class QVector;
 class QVariant;
 
-#if defined(Q_WS_QWS) || defined(Q_WS_X11) || defined(Q_WS_MAC)
+#if defined(Q_WS_QWS) || defined(Q_WS_X11) || defined(Q_WS_MAC) || defined(Q_WS_WIN) || defined(Q_OS_SYMBIAN)
 struct QRegionPrivate;
 #endif
 
@@ -86,12 +97,16 @@ public:
 
     // ### Qt 5: make these four functions QT4_SUPPORT
     QRegion unite(const QRegion &r) const;
+    QRegion unite(const QRect &r) const;
     QRegion intersect(const QRegion &r) const;
+    QRegion intersect(const QRect &r) const;
     QRegion subtract(const QRegion &r) const;
     QRegion eor(const QRegion &r) const;
 
     inline QRegion united(const QRegion &r) const { return unite(r); }
+    inline QRegion united(const QRect &r) const { return unite(r); }
     inline QRegion intersected(const QRegion &r) const { return intersect(r); }
+    inline QRegion intersected(const QRect &r) const { return intersect(r); }
     inline QRegion subtracted(const QRegion &r) const { return subtract(r); }
     inline QRegion xored(const QRegion &r) const { return eor(r); }
 
@@ -101,15 +116,23 @@ public:
     QRect boundingRect() const;
     QVector<QRect> rects() const;
     void setRects(const QRect *rect, int num);
+#ifdef QT_DEPRECATED
+    QT_DEPRECATED int numRects() const;
+#endif
+    int rectCount() const;
 
     const QRegion operator|(const QRegion &r) const;
     const QRegion operator+(const QRegion &r) const;
+    const QRegion operator+(const QRect &r) const;
     const QRegion operator&(const QRegion &r) const;
+    const QRegion operator&(const QRect &r) const;
     const QRegion operator-(const QRegion &r) const;
     const QRegion operator^(const QRegion &r) const;
     QRegion& operator|=(const QRegion &r);
     QRegion& operator+=(const QRegion &r);
+    QRegion& operator+=(const QRect &r);
     QRegion& operator&=(const QRegion &r);
+    QRegion& operator&=(const QRect &r);
     QRegion& operator-=(const QRegion &r);
     QRegion& operator^=(const QRegion &r);
 
@@ -122,14 +145,25 @@ public:
 #endif
 #ifndef qdoc
 #if defined(Q_WS_WIN)
-    inline HRGN    handle() const { return d->rgn; }
+    inline HRGN    handle() const { ensureHandle(); return d->rgn; }
 #elif defined(Q_WS_X11)
     inline Region handle() const { if(!d->rgn) updateX11Region(); return d->rgn; }
 #elif defined(Q_WS_MAC)
+#if defined Q_WS_MAC32
+    RgnHandle toQDRgn() const;
+    RgnHandle toQDRgnForUpdate_sys() const;
+    static QRegion fromQDRgn(RgnHandle shape);
+#endif
+#ifdef QT_MAC_USE_COCOA
+    inline HIMutableShapeRef handle(bool unused = false) const
+    { Q_UNUSED(unused); return toHIMutableShape(); }
+#else
     inline RgnHandle handle() const { return handle(false); }
-    RgnHandle handle(bool require_rgn) const;
+    inline RgnHandle handle(bool) const { return toQDRgn(); }
+#endif
+    HIMutableShapeRef toHIMutableShape() const;
+    static QRegion fromHIShapeRef(HIShapeRef shape);
 #elif defined(Q_WS_QWS)
-    // QGfx_QWS needs this for region drawing
     inline void *handle() const { return d->qt_rgn; }
 #endif
 #endif
@@ -142,30 +176,34 @@ private:
     QRegion copy() const;   // helper of detach.
     void detach();
 #if defined(Q_WS_WIN)
+    void ensureHandle() const;
     QRegion winCombine(const QRegion &r, int num) const;
 #elif defined(Q_WS_X11)
     void updateX11Region() const;
     void *clipRectangles(int &num) const;
     friend void *qt_getClipRects(const QRegion &r, int &num);
 #elif defined(Q_WS_MAC)
-    friend QRegion qt_mac_convert_mac_region(RgnHandle rgn);
+    static OSStatus shape2QRegionHelper(int inMessage, HIShapeRef inShape,
+                                        const CGRect *inRect, void *inRefcon);
 #endif
     friend bool qt_region_strictContains(const QRegion &region,
                                          const QRect &rect);
     friend struct QRegionPrivate;
 
-    void exec(const QByteArray &ba, int ver = 0);
+#ifndef QT_NO_DATASTREAM
+    void exec(const QByteArray &ba, int ver = 0, QDataStream::ByteOrder byteOrder = QDataStream::BigEndian);
+#endif
     struct QRegionData {
-        QBasicAtomic ref;
+        QBasicAtomicInt ref;
 #if defined(Q_WS_WIN)
         HRGN   rgn;
 #elif defined(Q_WS_X11)
         Region rgn;
         void *xrectangles;
-#elif defined(Q_WS_MAC)
-        mutable RgnHandle rgn;
+#elif defined(Q_WS_MAC) && !defined(QT_MAC_USE_COCOA)
+        mutable RgnHandle unused; // Here for binary compatibility reasons. ### Qt 5 remove.
 #endif
-#if defined(Q_WS_QWS) || defined(Q_WS_X11) || defined(Q_WS_MAC)
+#if defined(Q_WS_QWS) || defined(Q_WS_X11) || defined(Q_WS_MAC) || defined(Q_WS_WIN) || defined(Q_OS_SYMBIAN)
         QRegionPrivate *qt_rgn;
 #endif
     };
@@ -190,6 +228,8 @@ Q_GUI_EXPORT QDataStream &operator>>(QDataStream &, QRegion &);
 Q_GUI_EXPORT QDebug operator<<(QDebug, const QRegion &);
 #endif
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QREGION_H
