@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the tools applications of the Qt Toolkit.
+** This file is part of the QtTest module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -51,6 +49,10 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
+QT_MODULE(Test)
+
 #define QVERIFY(statement) \
 do {\
     if (!QTest::qVerify((statement), #statement, "", __FILE__, __LINE__))\
@@ -123,11 +125,13 @@ namespace QTest
         return 0;
     }
 
+
     Q_TESTLIB_EXPORT char *toHexRepresentation(const char *ba, int length);
     Q_TESTLIB_EXPORT char *toString(const char *);
     Q_TESTLIB_EXPORT char *toString(const void *);
 
     Q_TESTLIB_EXPORT int qExec(QObject *testObject, int argc = 0, char **argv = 0);
+    Q_TESTLIB_EXPORT int qExec(QObject *testObject, const QStringList &arguments);
 
     Q_TESTLIB_EXPORT bool qVerify(bool statement, const char *statementStr, const char *description,
                                  const char *file, int line);
@@ -175,6 +179,7 @@ namespace QTest
                              toString<T>(t1), toString<T>(t2), actual, expected, file, line);
     }
 
+
     template <>
     Q_TESTLIB_EXPORT bool qCompare<float>(float const &t1, float const &t2,
                     const char *actual, const char *expected, const char *file, int line);
@@ -215,7 +220,22 @@ namespace QTest
     template <typename T1, typename T2>
     bool qCompare(T1 const &, T2 const &, const char *, const char *, const char *, int);
 
-#if defined(QT_COORD_TYPE) || defined(__arm__)
+#if defined(QT_COORD_TYPE) && (defined(QT_ARCH_ARM) || defined(QT_NO_FPU) || defined(QT_ARCH_WINDOWSCE))
+    template <>
+    inline bool qCompare<qreal, float>(qreal const &t1, float const &t2, const char *actual,
+                                 const char *expected, const char *file, int line)
+    {
+        return qCompare<qreal>(t1, qreal(t2), actual, expected, file, line);
+    }
+
+    template <>
+    inline bool qCompare<float, qreal>(float const &t1, qreal const &t2, const char *actual,
+                                 const char *expected, const char *file, int line)
+    {
+        return qCompare<qreal>(qreal(t1), t2, actual, expected, file, line);
+    }
+
+#elif defined(QT_COORD_TYPE) || defined(QT_ARCH_ARM) || defined(QT_NO_FPU) || defined(QT_ARCH_WINDOWSCE) || defined(QT_ARCH_SYMBIAN)
     template <>
     inline bool qCompare<qreal, double>(qreal const &t1, double const &t2, const char *actual,
                                  const char *expected, const char *file, int line)
@@ -271,6 +291,28 @@ namespace QTest
         return compare_string_helper(t1, t2, actual, expected, file, line);
     }
 #else  /* QTEST_NO_SPECIALIZATIONS */
+
+// In Symbian we have QTEST_NO_SPECIALIZATIONS defined, but still float related specialization
+// should be used. If QTEST_NO_SPECIALIZATIONS is enabled we get ambiguous overload errors.
+#if defined(QT_ARCH_SYMBIAN)
+    template <typename T1, typename T2>
+    bool qCompare(T1 const &, T2 const &, const char *, const char *, const char *, int);
+
+    template <>
+    inline bool qCompare<qreal, double>(qreal const &t1, double const &t2, const char *actual,
+                                 const char *expected, const char *file, int line)
+    {
+        return qCompare<float>(float(t1), float(t2), actual, expected, file, line);
+    }
+
+    template <>
+    inline bool qCompare<double, qreal>(double const &t1, qreal const &t2, const char *actual,
+                                 const char *expected, const char *file, int line)
+    {
+        return qCompare<float>(float(t1), float(t2), actual, expected, file, line);
+    }
+#endif
+
     inline bool qCompare(const char *t1, const char *t2, const char *actual,
                          const char *expected, const char *file, int line)
     {
@@ -304,6 +346,17 @@ namespace QTest
         return compare_string_helper(t1, t2, actual, expected, file, line);
     }
 
+    // NokiaX86 and RVCT do not like implicitly comparing bool with int
+#ifndef QTEST_NO_SPECIALIZATIONS
+    template <>
+#endif
+    inline bool qCompare(bool const &t1, int const &t2,
+                    const char *actual, const char *expected, const char *file, int line)
+    {
+        return qCompare<int>(int(t1), t2, actual, expected, file, line);
+    }
+
+
     template <class T>
     inline bool qTest(const T& actual, const char *elementName, const char *actualStr,
                      const char *expected, const char *file, int line)
@@ -315,6 +368,8 @@ namespace QTest
 
 #undef QTEST_COMPARE_DECL
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif
