@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -43,6 +43,7 @@
 #define QABSTRACTXMLRECEIVER_H
 
 #include <QtCore/QVariant>
+#include <QtCore/QScopedPointer>
 #include <QtXmlPatterns/QXmlNodeModelIndex>
 
 QT_BEGIN_HEADER
@@ -90,7 +91,7 @@ public:
 
 protected:
     QAbstractXmlReceiver(QAbstractXmlReceiverPrivate *d);
-    QAbstractXmlReceiverPrivate *d_ptr;
+    QScopedPointer<QAbstractXmlReceiverPrivate> d_ptr;
 
     void sendAsNode(const QPatternist::Item &outputItem);
 private:
