@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -85,77 +85,15 @@
 #include <net/if.h>
 #endif
 
-#ifdef QT_LARGEFILE_SUPPORT
-#define QT_STATBUF              struct stat64
-#define QT_STATBUF4TSTAT        struct stat64
-#define QT_STAT                 ::stat64
-#define QT_FSTAT                ::fstat64
-#define QT_LSTAT                ::lstat64
-#define QT_OPEN                 ::open64
-#define QT_TRUNCATE             ::truncate64
-#define QT_FTRUNCATE            ::ftruncate64
-#define QT_LSEEK                ::lseek64
-#else
-#define QT_STATBUF		struct stat
-#define QT_STATBUF4TSTAT	struct stat
-#define QT_STAT			::stat
-#define QT_FSTAT		::fstat
-#define QT_LSTAT		::lstat
-#define QT_OPEN                 ::open
-#define QT_TRUNCATE             ::truncate
-#define QT_FTRUNCATE            ::ftruncate
-#define QT_LSEEK                ::lseek
-#endif
+#define QT_USE_XOPEN_LFS_EXTENSIONS
+#include "../common/posix/qplatformdefs.h"
 
-#ifdef QT_LARGEFILE_SUPPORT
-#define QT_FOPEN                ::fopen64
-#define QT_FSEEK                ::fseeko64
-#define QT_FTELL                ::ftello64
-#define QT_FGETPOS              ::fgetpos64
-#define QT_FSETPOS              ::fsetpos64
-#define QT_FPOS_T               fpos64_t
-#define QT_OFF_T                off64_t
-#else
-#define QT_FOPEN                ::fopen
-#define QT_FSEEK                ::fseek
-#define QT_FTELL                ::ftell
-#define QT_FGETPOS              ::fgetpos
-#define QT_FSETPOS              ::fsetpos
-#define QT_FPOS_T               fpos_t
-#define QT_OFF_T                long
-#endif
-
-#define QT_STAT_REG		S_IFREG
-#define QT_STAT_DIR		S_IFDIR
-#define QT_STAT_MASK		S_IFMT
-#define QT_STAT_LNK		S_IFLNK
-#define QT_SOCKET_CONNECT	::connect
-#define QT_SOCKET_BIND		::bind
-#define QT_FILENO		fileno
-#define QT_CLOSE		::close
-#define QT_READ			::read
-#define QT_WRITE		::write
-#define QT_ACCESS		::access
-#define QT_GETCWD		::getcwd
-#define QT_CHDIR		::chdir
-#define QT_MKDIR		::mkdir
-#define QT_RMDIR		::rmdir
-#define QT_OPEN_LARGEFILE       O_LARGEFILE
-#define QT_OPEN_RDONLY		O_RDONLY
-#define QT_OPEN_WRONLY		O_WRONLY
-#define QT_OPEN_RDWR		O_RDWR
-#define QT_OPEN_CREAT		O_CREAT
-#define QT_OPEN_TRUNC		O_TRUNC
-#define QT_OPEN_APPEND		O_APPEND
-
-#define QT_SIGNAL_RETTYPE	void
-#define QT_SIGNAL_ARGS		int
-#define QT_SIGNAL_IGNORE	SIG_IGN
+#undef QT_SOCKLEN_T
 
 #if defined(__GLIBC__) && (__GLIBC__ >= 2)
-#define QT_SOCKLEN_T		socklen_t
+#define QT_SOCKLEN_T            socklen_t
 #else
-#define QT_SOCKLEN_T		int
+#define QT_SOCKLEN_T            int
 #endif
 
 #if defined(_XOPEN_SOURCE) && (_XOPEN_SOURCE >= 500)
@@ -163,5 +101,4 @@
 #define QT_VSNPRINTF		::vsnprintf
 #endif
 
-
 #endif // QPLATFORMDEFS_H
